@@ -634,6 +634,9 @@ def remove_webassets(conn):
     urls_to_ignore = [
         '/website/static/src/scss/options/user_values.custom.web.assets_common.scss',
         '/website/static/src/scss/options/colors/user_color_palette.custom.web.assets_common.scss',
+        '/website/static/src/scss/options/colors/user_theme_color_palette.custom.web.assets_common.scss',
+        '/website/static/src/scss/options/colors/user_gray_color_palette.scss',
+        '/website/static/src/scss/options/user_values.scss',
         '/web/static/src/scss/asset_styles_company_report.scss',
     ]
     ignore_url_str = ''
@@ -937,4 +940,4 @@ def git_diff_files(path, commit1, commit2):
         commit2,
     ], encoding='utf8', cwd=path)
     filepaths = list(filter(bool, output.splitlines()))
-    return filepaths
\ No newline at end of file
+    return filepaths
